import requests

def input(account_id, region):
    url = f"https://teamxdarks-api.vercel.app/profile_info?uid={account_id}&region={region}&key=teamXKrishna"
    response = requests.get(url)
    
    if response.status_code == 200:
        return response.json()
    else:
        return {"error": "Failed to fetch data"}


from setuptools import setup, find_packages

setup(
    name="princeffinfo",
    version="0.1.2",
    packages=find_packages(),
    install_requires=[
        "requests",
    ],
    description="A package to fetch Free Fire account info.",
    author="PRINCE-LK",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)